#
# spec file for package varnish
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           varnish
%define library_name libvarnishapi1
Version:        4.0.3
Release:        5.7
Summary:        Varnish is a high-performance HTTP accelerator
License:        BSD-2-Clause
Group:          Productivity/Networking/Web/Proxy
Url:            http://varnish-cache.org/

#Git-Clone:	git://git.varnish-cache.org/varnish-cache
#Git-Web:	https://varnish-cache.org/trac/browser
Source:		https://repo.varnish-cache.org/source/%name-%version.tar.gz
Source3:        varnish.sysconfig
Source5:        varnish.logrotate
Source7:        varnish.service
Source8:        varnishlog.service
Patch1:         0001-Fail-fetch-on-malformed-Content-Length-header.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libxslt
BuildRequires:  ncurses-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  python-docutils
BuildRequires:  xz
Prereq(post):	%_sbindir/useradd %_sbindir/groupadd
%if 0%{?suse_version} >= 1010
Recommends:     logrotate
%endif
BuildRequires:  systemd-rpm-macros
%define pkg_home     %_localstatedir/lib/%name
%define pkg_logdir   %_localstatedir/log/%name
%define pkg_cachedir %_localstatedir/cache/%name
Requires:       c_compiler

%description
Varnish is an HTTP accelerator. An HTTP accelerator (often called Reverse
Proxy) is an application that stores (caches) documents that have been
requested over the HTTP protocol.

Based on certain criteria the next client requesting the document is either
given the cached document, or a "fresh" document requested from a backend
server. The purpose of this is to minimize the requests going to the backend
server(s) by serving the same document to potentially many users.

%package -n %library_name
Summary:        Shared libraries for Varnish
Group:          Productivity/Networking/Web/Proxy

%description -n %library_name
Varnish is an HTTP accelerator. An HTTP accelerator (often called Reverse
Proxy) is an application that stores (caches) documents that have been
requested over the HTTP protocol.

Based on certain criteria the next client requesting the document is either
given the cached document, or a "fresh" document requested from a backend
server. The purpose of this is to minimize the requests going to the backend
server(s) by serving the same document to potentially many users.

This package holds the shared libraries for varnish.

%package devel
Requires:       %name = %version
Summary:        Development files for Varnish
Group:          Development/Libraries/C and C++

%description devel
Varnish is an HTTP accelerator. An HTTP accelerator (often called Reverse
Proxy) is an application that stores (caches) documents that have been
requested over the HTTP protocol.

Based on certain criteria the next client requesting the document is either
given the cached document, or a "fresh" document requested from a backend
server. The purpose of this is to minimize the requests going to the backend
server(s) by serving the same document to potentially many users.

This package holds the development files for varnish.

%prep
%setup -q
%patch -P 1 -p1

%build
export CFLAGS="%optflags -fstack-protector"
%configure --disable-static --docdir="%_docdir/%name" \
           --localstatedir=%_localstatedir/cache/ \
           --enable-developer-warnings
make %{?_smp_mflags}

%install
b="%buildroot";
%make_install
# There is no use for them to normal users
mv "$b/%_bindir"/* "$b/%_sbindir/";
#
##missing directories
install -dm 0755 "$b"/{%pkg_logdir,%pkg_home};
install -Dpm 0644 "%{S:5}" "$b/%_sysconfdir/logrotate.d/varnish";
#
##init scripts
install -Dpm 0644 "%{S:3}" "$b/var/adm/fillup-templates/sysconfig.%name";
install -Dpm 0644 "%{S:7}" "$b/%_unitdir/varnish.service";
install -Dpm 0644 "%{S:8}" "$b/%_unitdir/varnishlog.service";
mkdir -p "$b/%_sbindir";
ln -s service "$b/%_sbindir/rcvarnish";
ln -s service "$b/%_sbindir/rcvarnishlog";
#
##config files
mkdir -p "$b/%_sysconfdir/%name"
cp "$b/%_docdir/%name/example.vcl" "$b/%_sysconfdir/%name/vcl.conf"

find "$b" -type f -name "*.la" -delete
mkdir -p "$b/%pkg_logdir"
mkdir -p "$b/%_docdir/%name"
cp -a ChangeLog LICENSE README "$b/%_docdir/%name/"

%pre
%_bindir/getent group varnish >/dev/null || \
	%_sbindir/groupadd -r varnish || :
%_bindir/getent passwd varnish >/dev/null || \
	%_sbindir/useradd -g varnish -s /bin/false -r -c "user for Varnish" \
		-d %pkg_home varnish || :
%service_add_pre varnish.service
%service_add_pre varnishlog.service

%post
%service_add_post varnish.service
%service_add_post varnishlog.service

%preun
%service_del_preun varnish.service
%service_del_preun varnishlog.service

%postun
%service_del_postun varnish.service
%service_del_postun varnishlog.service

%post   -n %library_name -p /sbin/ldconfig
%postun -n %library_name -p /sbin/ldconfig

%files
%defattr(-,root,root)
%_unitdir/*.service
%config(noreplace) %_sysconfdir/logrotate.d/varnish
%dir %attr(0750,root,varnish) %_sysconfdir/%name/
%config(noreplace) %attr(0640,root,varnish) %_sysconfdir/%name/vcl.conf
%_libdir/varnish
%_sbindir/varnish*
%_sbindir/rcvarnish*
%_mandir/man*/*
%_docdir/%name/
%_datadir/%name/
%dir %attr(0750,varnish,varnish) %pkg_home
%dir %attr(0750,varnish,varnish) %pkg_cachedir
%dir %attr(0750,varnish,varnish) %pkg_logdir
%_localstatedir/adm/fillup-templates/sysconfig.%name

%files -n %library_name
%defattr(-,root,root,-)
%_libdir/libvarnishapi.so.1*

%files devel
%defattr(-,root,root,-)
%_includedir/varnish
%_datadir/aclocal/
%_libdir/pkgconfig/*
%_libdir/libvarnishapi.so

%changelog
* Fri Mar 27 2015 jengelh@inai.de
- Update to new upstream release 4.0.3
  * Full support for streaming objects through from the backend on a
  cache miss. Bytes will be sent to 1..n requesting clients as they
  come in from the backend server.
  * Background (re)fetch of expired objects. On a cache miss where a
  stale copy is available, serve the client the stale copy while
  fetching an updated copy from the backend in the background.
  * New varnishlog query language, allowing automatic grouping of
  requests when debugging ESI or a failed backend request.
  * Comprehensive request timestamp and byte counters.
- Add 0001-Fail-fetch-on-malformed-Content-Length-header.patch
  [bnc#921316]
* Fri Jan  3 2014 danimo@owncloud.com
- Updated to 3.0.5, contains fix for CVE-2013-4484
  * A bad interaction between -b, -c and -m in the varnishlog tool
  has been fixed.
  * A malformed request could in some configurations lead to Varnish
  crashing has been corrected. (CVE-2013-4484)
  * Duplicate Content-Length headers were in some cases sent to
  clients when streaming is enabled, this has been fixed.
  * ESI parse errors are no longer printed to standard output.
  * Stop segfaulting if the first part of a synthetic page is NULL.
- Remove 0001-Make-up-our-mind-Any-req.-we-receive-from-the-client.patch
  and varnish-disable-pcrejit.diff (merged upstream)
* Fri Nov  1 2013 jengelh@inai.de
- Add 0001-Make-up-our-mind-Any-req.-we-receive-from-the-client.patch
  (CVE-2013-4484, bnc#48451)
* Fri Oct  4 2013 jengelh@inai.de
- Deactivate libpcre JIT (bnc#839358), add varnish-disable-pcrejit.diff
* Sun Sep 23 2012 nmo.marques@gmail.com
- Update to version 3.0.3
  * Fixed excessive session workspace allocations.
  * Fixed some crashes in the case of out of memory
  * Fixed an infinite loop in the regex parser.
  * DNS director now uses port 80 by default if not specified.
  * Introduce idle_send_timeout and increase default value for
  send_timeout to 600s. This allows a long send timeout for slow
  clients while still being able to disconnect idle clients.
  * Fixed a crash when passing with streaming on.
  * Fixed a crash in the idle session timeout code.
  * Fixed an issue where the poll waiter did not timeout clients if
  all clients were idle.
  * Log regex errors instead of crashing.
  * Introduce pcre_match_limit, and pcre_match_limit_recursion
  parameters.
  * Add CLI commands to manually control health state of a
  backend.
* Wed Feb  8 2012 jengelh@medozas.de
- Update to new upstream release 3.0.2
  * Add support for ESI and gzip
  * Handle objects larger than 2G
  * HTTP Range support is now enabled by default
  * "307 Temporary redirect" is now considered cacheable
  * see ChangeLog (packaged) or
  http://varnish-cache.org/trac/browser/doc/changes.rst
  for details
- Note that the -s file,/var/cache/varnish,524288 argument (check
  /etc/sysconfig/varnish) needs at least "1M" instead of 524288
  or the daemon will not start anymore.
- Add systemd unit files
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue May 10 2011 crrodriguez@opensuse.org
- Varnish Requires a C compiler, the vcl scripts are compiled
  and loaded as DSO.
* Sat Apr 16 2011 crrodriguez@opensuse.org
- remove configure option --enable-debugging-symbols
  it overrides buildsystem optimization levels.
* Sat Apr 16 2011 crrodriguez@opensuse.org
- Update to version 2.1.5
  * Two bugs relating to Content-Length and possible duplication
    of Content-Length headers have been resolved.
  * Fixed an issue with re-using connections after Chunked-Encoding.
  * Use the time of cache-insertion for "If-Modified-Since" requests
    if a "Last-Modified" header isn't provided by the backend.
  * Merge multi-line Vary and Cache-Control headers from clients,
    which Google Chromium seem to split up.
* Fri Apr 15 2011 mrueckert@suse.de
- use pkgconfig instead of pkg-config on SLES 9
* Sun Apr  3 2011 jengelh@medozas.de
- Fix security-problematic ownership of /etc/varnish files
  (bnc#678811)
- Run spec-beautifier over it
- Replace default shipped vcl.conf by something working
- Run as varnish user
- Start varnishlog together with varnishd
- Properly use PID files in init script
* Sat Oct  9 2010 jengelh@medozas.de
- Create and package /var/log/varnish
* Thu Aug  5 2010 jengelh@medozas.de
- Update to new upstream release: 2.1.3
  * fixed an off-by-one error in the ESI handling causing includes to
  fail a large part of the time.
  * Avoid triggering an assert if the other end closes the connection
  while we are lingering and waiting for another request from them.
  * Make it possible to specify the per-thread stack size. This might
  be useful on 32 bit systems with their limited address space.
  * Persistent storage is now experimentally supported using the
  persistent stevedore. It has the same command line arguments as
  the file stevedore.
  * The regular expression engine is now PCRE instead of POSIX
  regular expressions.
  * Add a new hashing method called critbit. This autoscales and
  should work better on large object workloads than the classic
  hash. Critbit has been made the default hash algorithm.
  * Add support for authenticating CLI connections.
  * Add hash director that chooses which backend to use depending on
  req.hash.
  * Add client director that chooses which backend to use depending
  on the client's IP address. Note that this ignores the
  X-Forwarded-For header.
  * Add a timestamp to bans, so you can know how old they are.
  * Varnish can now connect its CLI to a remote instance when
  starting up, rather than just being connected to.
  * It is no longer needed to specify the maximum number of HTTP
  headers to allow from backends. This is now a run-time parameter.
  * HEAD requests would be converted to GET requests too early, which
  affected pass and pipe. This has been fixed.
  * Add experimental support for the Range header. This has to be
  enabled using the parameter http_range_support.
- Add PreReqs for %%post
- Run %%setup quietly
- Remove unneeded .la files from installation - libraries are in
  a standard directory already
- Avoid use of bash-specific &>/dev/null during %%post
- Refine file lists
- Remove old changelog from .spec - changelog is in .changes
* Tue Dec 15 2009 jg@internetx.de
- update 2.0.5
* Fri Apr  3 2009 mrueckert@suse.de
- update to 2.0.4
* Tue Mar 10 2009 mrueckert@suse.de
- update to 2.0.3
* Wed Jul 25 2007 mrueckert@suse.de
- updated to 1.1
* Tue Feb 20 2007 mrueckert@suse.de
- update to version 1.0.3
  Consistency issues with statistics and backend parameters were
  fixed. Parsing of -w command-line options was fixed. A
  short-lived DNS cache was added to avoid thrashing DNS servers
  when the backend fails.
* Sat Dec  2 2006 mrueckert@suse.de
- fixing build on sles9
- added files from the official rh4 rpm:
  o init scripts for non suse distros
  o the default configs for all distros
- added init/sysconfig script for suse.
- we create a user now. Remaining TODO item: how to run varnish as
  non root user on port 80?
* Sun Nov 19 2006 mrueckert@suse.de
- update to 1.0.2
